Package: deckgl
Title: An R Interface to 'deck.gl'
Version: 0.3.0
Date: 2023-02-19
Authors@R: person("Stefan", "Kuethe", email = "crazycapivara@gmail.com", role = c("aut", "cre"))
Maintainer: Stefan Kuethe <crazycapivara@gmail.com>
Description: Makes 'deck.gl' <https://deck.gl/>, a WebGL-powered open-source JavaScript framework
  for visual exploratory data analysis of large datasets, available within R via the 'htmlwidgets' package.
  Furthermore, it supports basemaps from 'mapbox' <https://www.mapbox.com/> via
  'mapbox-gl-js' <https://github.com/mapbox/mapbox-gl-js>.
URL: https://github.com/crazycapivara/deckgl/,
        https://crazycapivara.github.io/deckgl/
BugReports: https://github.com/crazycapivara/deckgl/issues/
Depends: R (>= 3.3)
Imports: htmlwidgets, htmltools, magrittr, base64enc, yaml, jsonlite,
        readr, tibble
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.0
Suggests: knitr, rmarkdown, testthat, rprojroot, sf, scales,
        RColorBrewer, shiny
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-02-19 20:07:28 UTC; gabbo
Author: Stefan Kuethe [aut, cre]
Repository: CRAN
Date/Publication: 2023-02-19 20:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 17:33:02 UTC; unix
