# Generated by roxygen2: do not edit by hand

export("%<>%")
export("%>%")
export(JS)
export(add_arc_layer)
export(add_basemap)
export(add_bitmap_layer)
export(add_column_layer)
export(add_contour_layer)
export(add_control)
export(add_data)
export(add_geojson_layer)
export(add_great_circle_layer)
export(add_grid_cell_layer)
export(add_grid_layer)
export(add_h3_cluster_layer)
export(add_h3_hexagon_layer)
export(add_heatmap_layer)
export(add_hexagon_layer)
export(add_icon_layer)
export(add_json_editor)
export(add_layer)
export(add_legend)
export(add_legend_pal)
export(add_line_layer)
export(add_mapbox_basemap)
export(add_path_layer)
export(add_point_cloud_layer)
export(add_polygon_layer)
export(add_raster_tile_layer)
export(add_scatterplot_layer)
export(add_screen_grid_layer)
export(add_source)
export(add_source_as_dep)
export(add_text_layer)
export(deckgl)
export(deckglOutput)
export(deckgl_proxy)
export(does_it_work)
export(encode_icon_atlas)
export(get_color_to_rgb_array)
export(get_data)
export(get_first_element)
export(get_last_element)
export(get_position)
export(get_property)
export(onRender)
export(renderDeckgl)
export(set_view_state)
export(update_deckgl)
export(use_carto_style)
export(use_contour_definition)
export(use_default_icon_properties)
export(use_icon_definition)
export(use_tooltip)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,onRender)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(tibble,tibble)
