#!/bin/sh

# get latest version
#wget https://unpkg.com/mapbox-gl

# wget https://unpkg.com/mapbox-gl@0.48.0/dist/mapbox-gl.js
# wget https://unpkg.com/mapbox-gl@0.48.0/dist/mapbox-gl.css

# get latest
wget https://unpkg.com/mapbox-gl/dist/mapbox-gl.js
wget https://unpkg.com/mapbox-gl/dist/mapbox-gl.css

